Unified Framework for Hydrology
-------------------------------

.. image:: https://img.shields.io/pypi/v/unifhy?style=flat-square&color=00b0f0
   :target: https://pypi.python.org/pypi/unifhy
   :alt: PyPI Version
.. image:: https://img.shields.io/badge/dynamic/json?url=https://zenodo.org/api/records/4726695&label=doi&query=doi&style=flat-square&color=00b0f0
   :target: https://zenodo.org/badge/latestdoi/234523723
   :alt: DOI
.. image:: https://img.shields.io/github/license/unifhy-org/unifhy?style=flat-square&color=00b0f0
   :target: https://opensource.org/licenses/BSD-3-Clause
   :alt: Licence
.. image:: https://img.shields.io/badge/fair-%E2%97%8F%20%20%E2%97%8F%20%20%E2%97%8F%20%20%E2%97%8F%20%20%E2%97%8B-yellow?style=flat-square
   :target: https://fair-software.eu
   :alt: FAIR Software Compliance
.. image:: https://img.shields.io/github/workflow/status/unifhy-org/unifhy/Basic%20tests?style=flat-square&label=tests
   :target: https://github.com/unifhy-org/unifhy/actions/workflows/basic_tests.yml
   :alt: Tests Status

The Python package `unifhy` (Unified Framework for Hydrology) is a hydrological 
modelling framework which combines interchangeable modelling components for the 
surface layer, subsurface, and open water parts of the terrestrial water cycle. 
It is designed to foster collaborations between land surface, hydrological, and 
groundwater modelling communities.
